Class: CyberSource::InlineResponse2002PaymentInformationTokenizedCard

Inherits:
Object
  • Object
show all
Defined in:
lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InlineResponse2002PaymentInformationTokenizedCard

Initializes the object



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 56

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'prefix')
    self.prefix = attributes[:'prefix']
  end

  if attributes.has_key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'expirationMonth')
    self.expiration_month = attributes[:'expirationMonth']
  end

  if attributes.has_key?(:'expirationYear')
    self.expiration_year = attributes[:'expirationYear']
  end
end

Instance Attribute Details

#expiration_monthObject

Two-digit month in which the payment network token expires. ‘Format: MM`. Possible values: 01 through 12.



27
28
29
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 27

def expiration_month
  @expiration_month
end

#expiration_yearObject

Four-digit year in which the payment network token expires. ‘Format: YYYY`.



30
31
32
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 30

def expiration_year
  @expiration_year
end

#prefixObject

First six digits of token. CyberSource includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.



18
19
20
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 18

def prefix
  @prefix
end

#suffixObject

Last four digits of token. CyberSource includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.



21
22
23
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 21

def suffix
  @suffix
end

#typeObject

Type of card to authorize. - 001 Visa - 002 Mastercard - 003 Amex - 004 Discover



24
25
26
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 24

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 33

def self.attribute_map
  {
    :'prefix' => :'prefix',
    :'suffix' => :'suffix',
    :'type' => :'type',
    :'expiration_month' => :'expirationMonth',
    :'expiration_year' => :'expirationYear'
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 44

def self.swagger_types
  {
    :'prefix' => :'String',
    :'suffix' => :'String',
    :'type' => :'String',
    :'expiration_month' => :'String',
    :'expiration_year' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



173
174
175
176
177
178
179
180
181
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      prefix == o.prefix &&
      suffix == o.suffix &&
      type == o.type &&
      expiration_month == o.expiration_month &&
      expiration_year == o.expiration_year
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 219

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 285

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 198

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


185
186
187
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 185

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



191
192
193
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 191

def hash
  [prefix, suffix, type, expiration_month, expiration_year].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 85

def list_invalid_properties
  invalid_properties = Array.new
  if !@prefix.nil? && @prefix.to_s.length > 6
    invalid_properties.push('invalid value for "prefix", the character length must be smaller than or equal to 6.')
  end

  if !@suffix.nil? && @suffix.to_s.length > 4
    invalid_properties.push('invalid value for "suffix", the character length must be smaller than or equal to 4.')
  end

  if !@type.nil? && @type.to_s.length > 3
    invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 3.')
  end

  if !@expiration_month.nil? && @expiration_month.to_s.length > 2
    invalid_properties.push('invalid value for "expiration_month", the character length must be smaller than or equal to 2.')
  end

  if !@expiration_year.nil? && @expiration_year.to_s.length > 4
    invalid_properties.push('invalid value for "expiration_year", the character length must be smaller than or equal to 4.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



265
266
267
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 265

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



259
260
261
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 259

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



112
113
114
115
116
117
118
119
# File 'lib/cyberSource_client/models/inline_response_200_2_payment_information_tokenized_card.rb', line 112

def valid?
  return false if !@prefix.nil? && @prefix.to_s.length > 6
  return false if !@suffix.nil? && @suffix.to_s.length > 4
  return false if !@type.nil? && @type.to_s.length > 3
  return false if !@expiration_month.nil? && @expiration_month.to_s.length > 2
  return false if !@expiration_year.nil? && @expiration_year.to_s.length > 4
  true
end