Class: CyberSource::V2paymentsProcessingInformationCaptureOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V2paymentsProcessingInformationCaptureOptions

Initializes the object



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 46

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'captureSequenceNumber')
    self.capture_sequence_number = attributes[:'captureSequenceNumber']
  end

  if attributes.has_key?(:'totalCaptureCount')
    self.total_capture_count = attributes[:'totalCaptureCount']
  end

  if attributes.has_key?(:'dateToCapture')
    self.date_to_capture = attributes[:'dateToCapture']
  end
end

Instance Attribute Details

#capture_sequence_numberObject

Capture number when requesting multiple partial captures for one payment. Used along with totalCaptureCount to track which capture is being processed. For example, the second of five captures would be passed to CyberSource as: - captureSequenceNumber = 2, and - totalCaptureCount = 5



18
19
20
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 18

def capture_sequence_number
  @capture_sequence_number
end

#date_to_captureObject

Date on which you want the capture to occur. This field is supported only for **CyberSource through VisaNet**. ‘Format: MMDD`



24
25
26
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 24

def date_to_capture
  @date_to_capture
end

#total_capture_countObject

Total number of captures when requesting multiple partial captures for one payment. Used along with captureSequenceNumber which capture is being processed. For example, the second of five captures would be passed to CyberSource as: - captureSequenceNumber = 2, and - totalCaptureCount = 5



21
22
23
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 21

def total_capture_count
  @total_capture_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 27

def self.attribute_map
  {
    :'capture_sequence_number' => :'captureSequenceNumber',
    :'total_capture_count' => :'totalCaptureCount',
    :'date_to_capture' => :'dateToCapture'
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 36

def self.swagger_types
  {
    :'capture_sequence_number' => :'Float',
    :'total_capture_count' => :'Float',
    :'date_to_capture' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



143
144
145
146
147
148
149
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capture_sequence_number == o.capture_sequence_number &&
      total_capture_count == o.total_capture_count &&
      date_to_capture == o.date_to_capture
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 187

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 253

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 166

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


153
154
155
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 153

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



159
160
161
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 159

def hash
  [capture_sequence_number, total_capture_count, date_to_capture].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 67

def list_invalid_properties
  invalid_properties = Array.new
  if !@capture_sequence_number.nil? && @capture_sequence_number > 99
    invalid_properties.push('invalid value for "capture_sequence_number", must be smaller than or equal to 99.')
  end

  if !@capture_sequence_number.nil? && @capture_sequence_number < 1
    invalid_properties.push('invalid value for "capture_sequence_number", must be greater than or equal to 1.')
  end

  if !@total_capture_count.nil? && @total_capture_count > 99
    invalid_properties.push('invalid value for "total_capture_count", must be smaller than or equal to 99.')
  end

  if !@total_capture_count.nil? && @total_capture_count < 1
    invalid_properties.push('invalid value for "total_capture_count", must be greater than or equal to 1.')
  end

  if !@date_to_capture.nil? && @date_to_capture.to_s.length > 4
    invalid_properties.push('invalid value for "date_to_capture", the character length must be smaller than or equal to 4.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



233
234
235
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 233

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



227
228
229
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 227

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



94
95
96
97
98
99
100
101
# File 'lib/cyberSource_client/models/v2payments_processing_information_capture_options.rb', line 94

def valid?
  return false if !@capture_sequence_number.nil? && @capture_sequence_number > 99
  return false if !@capture_sequence_number.nil? && @capture_sequence_number < 1
  return false if !@total_capture_count.nil? && @total_capture_count > 99
  return false if !@total_capture_count.nil? && @total_capture_count < 1
  return false if !@date_to_capture.nil? && @date_to_capture.to_s.length > 4
  true
end